
.\" Copyright (c), 2005 Dan McMahill
.\" Do not edit this directly.  Edit the XML source file instead
.\"

.TH microstrip_calc "n" "" "Wcalc" "Wcalc Commands"
.B microstrip_calc
- Symmetric microstrip transmission line analysis

.SH SYNOPSIS
microstrip_calc w h l tmet rho rough er tand f 

.SH INPUT PARAMETERS

.TP 10
w
: width of microstrip line (meters)
.TP 10
h
: substrate thickness (meters)
.TP 10
l
: lentgh of microstrip line (meters)
.TP 10
tmet
: metal thickness (meters)
.TP 10
rho
: resistivity of the line (relative to copper)
.TP 10
rough
: conductor surface roughness (meters-rms)
.TP 10
er
: substrate relative permitivitty
.TP 10
tand
: substrate loss tangent
.TP 10
f
: analysis frequency (Hz)

.SH OUTPUT VALUES

.TP 10
z0
: calculated characteristic impedance (Ohms)
.TP 10
keff
: calculated effective relative permitivity
.TP 10
elen
: calculated electrical length of the line (degrees)
.TP 10
loss
: calculated loss of the line (dB)
.TP 10
L
: calculated inductance per length (Henries/meter)
.TP 10
R
: calculated resistance per length (Ohms/meter)
.TP 10
C
: calculated capacitance per length (Farads/meter)
.TP 10
G
: calculated conductance per length (Siemens/meter)
.TP 10
lc
: conductor loss (dB/meter)
.TP 10
ld
: dielectric loss (dB/meter)
.TP 10
deltal
: calculated open circuit end correction (meters)
.TP 10
depth
: calculated skin depth (meters)
.SH DESCRIPTION

Function to analyze the electrical characteristics of a single 
microstrip transmission line. The physical
dimensions of the microstrip line are given as inputs and the
characteristic impedance, effective dielectric constant, loss and
open circuit end correction are calculated.

The model accounts for dispersion (frequency dependent propagation
velocity).


.NF



                 |<--W-->|
                  _______    
                 | metal | <- rho,rough
    ----------------------------------------------
   (  dielectric                         /|\\     (
    )   er,tand                       H   |       )
   (                                     \\|/     (
    ----------------------------------------------
    XXXXXXXXXXXXXXXXXX ground XXXXXXXXXXXXXXXXXXXX



.FI

.SH EXAMPLE
.nf

*
* Z0 = 50 Ohms, Keff = 6.972
microstrip_calc 0.877e-3 1e-3 1.0 3e-5 1.72e-8 0.0 9.60 0.0 1e10
* Z0 = 75 Ohms, Keff = 2.033
microstrip_calc 1.379e-3 1e-3 1.0 3e-5 1.72e-8 0.0 2.55 0.0 1e6
*
  
.fi
.SH SEE ALSO
stdio-wcalc(1),
air_coil_calc(n), air_coil_syn(n), coax_calc(n), coax_syn(n), coupled_microstrip_calc(n), coupled_microstrip_syn(n), ic_microstrip_calc(n), ic_microstrip_syn(n), microstrip_calc(n), microstrip_syn(n), stripline_calc(n), stripline_syn(n)
.SH AUTHOR

Dan McMahill

.SH BUGS

None known
